@@ -18,7 +18,7 @@ class Tier(object):
         self.tier_type = None
 
     def add_point(self, point):
-        """Adds point to the Tier."""
+        """Add point to the Tier."""
         point = Point(point.time, point.value, superior_PitchTier=self)
         
         if point.time < self.start_time or point.time > self.end_time:
@@ -40,7 +40,7 @@ class Tier(object):
         self._indexed = True
 
     def add_points(self, points):
-        """Adds points to the Tier."""
+        """Add points to the Tier."""
         
         for point in points:
             point = Point(point.time, point.value, superior_PitchTier=self)
@@ -64,7 +64,7 @@ class Tier(object):
         self._indexed = True
     
     def to_plot(self, start_time=None, end_time=None):
-        """Plots the points of the Tier from between two time points. If the time points are not specified, start time and end time are used. To change related parameters, use parameters."""
+        """Plot the points of the Tier from between two time points. If the time points are not specified, start time and end time are used. To change related parameters, use parameters."""
         import seaborn as sns
         from matplotlib import pyplot as plt
 
@@ -405,7 +405,7 @@ class Point(object):
     
     @property
     def superior_PitchTier(self):
-        """The PitchTier this Point object belongs to."""
+        """The PitchTier to which this Point object belongs."""
         
         return self.__superior_PitchTier
                 
