@@ -1,8 +1,8 @@
 from pytiers.core import PitchTier, DurationTier, Point
 import os
 
-def read_Tier(file):
-    """Reads Praat\'s PitchTier and DurationTier."""
+def read_tier(file):
+    """Read Praat\'s PitchTier and DurationTier."""
     
     def findby_initial_str(strs, initial_str):
         for this_str in strs:
